@@ -19,9 +19,12 @@ def stream(func):
     @wraps(func)
     def wrapped(manager, *args, **kwargs):
         offset, limit = kwargs.pop('_offset', None), kwargs.pop('_limit', None)
-        try:
-            return func(manager, *args, **kwargs)[offset:limit]\
-                .fetch_generic_relations()
-        except AttributeError:
-            return func(manager, *args, **kwargs).fetch_generic_relations()
+        qs = func(manager, *args, **kwargs)
+        if isinstance(qs, dict):
+            qs = manager.public(**qs)
+        elif isinstance(qs, (list, tuple)):
+            qs = manager.public(*qs)
+        if offset or limit:
+            qs = qs[offset:limit]
+        return qs.fetch_generic_relations()
     return wrapped
